==> eslint-plugin-total-functions-5.0.1.tgz: package/src/rules/no-unsafe-optional-property-assignment.ts <==
import { RuleModule } from "@typescript-eslint/experimental-utils/dist/ts-eslint";
import { isSymbolFlagSet } from "tsutils";
import { Symbol, SymbolFlags } from "typescript";
import {
  createNoUnsafeAssignmentRule,
  MessageId,
  UnsafeIndexAssignmentFunc,
  UnsafePropertyAssignmentFunc,
} from "./unsafe-assignment-rule";

// eslint-disable-next-line functional/functional-parameters
const unsafeIndexAssignmentFunc: UnsafeIndexAssignmentFunc = (): boolean =>
  false;

const unsafePropertyAssignmentFunc: UnsafePropertyAssignmentFunc = (
  // eslint-disable-next-line @typescript-eslint/ban-types
  destinationProperty: Symbol,
  // eslint-disable-next-line @typescript-eslint/ban-types
  sourceProperty: Symbol | undefined
): boolean => {
  const destinationPropIsOptional = isSymbolFlagSet(
    destinationProperty,
    SymbolFlags.Optional
  );

  return destinationPropIsOptional && sourceProperty === undefined;
};

const message =
  "Assigning to an optional property when there is no such property in the source type (optional or otherwise) is unsafe.";

/**
 * An ESLint rule to ban unsafe assignment to optional properties.
 */
// eslint-disable-next-line total-functions/no-unsafe-readonly-mutable-assignment
const noUnsafeOptionalPropertyAssignment: RuleModule<MessageId, readonly []> = {
  meta: {
    type: "problem",
    docs: {
      description: "Bans unsafe assignment to optional properties.",
      recommended: "error",
      url: "https://github.com/danielnixon/eslint-plugin-total-functions",
    },
    messages: {
      errorStringCallExpression: message,
      errorStringAssignmentExpression: message,
      errorStringVariableDeclaration: message,
      errorStringArrowFunctionExpression: message,
      errorStringTSAsExpression: message,
      errorStringTSTypeAssertion: message,
    },
    schema: [],
  },
  create: createNoUnsafeAssignmentRule(
    unsafePropertyAssignmentFunc,
    unsafeIndexAssignmentFunc
  ),
} as const;

export default noUnsafeOptionalPropertyAssignment;

==> eslint-plugin-total-functions-6.0.0.tgz: package/src/rules/no-unsafe-optional-property-assignment.ts <==
import { isSymbolFlagSet } from "tsutils";
import { Symbol, SymbolFlags } from "typescript";
import { createRule } from "./common";
import {
  createNoUnsafeAssignmentRule,
  UnsafeIndexAssignmentFunc,
  UnsafePropertyAssignmentFunc,
} from "./unsafe-assignment-rule";

// eslint-disable-next-line functional/functional-parameters
const unsafeIndexAssignmentFunc: UnsafeIndexAssignmentFunc = (): boolean =>
  false;

const unsafePropertyAssignmentFunc: UnsafePropertyAssignmentFunc = (
  // eslint-disable-next-line @typescript-eslint/ban-types
  destinationProperty: Symbol,
  // eslint-disable-next-line @typescript-eslint/ban-types
  sourceProperty: Symbol | undefined
): boolean => {
  const destinationPropIsOptional = isSymbolFlagSet(
    destinationProperty,
    SymbolFlags.Optional
  );

  return destinationPropIsOptional && sourceProperty === undefined;
};

const message =
  "Assigning to an optional property when there is no such property in the source type (optional or otherwise) is unsafe.";

/**
 * An ESLint rule to ban unsafe assignment to optional properties.
 */
// eslint-disable-next-line total-functions/no-unsafe-readonly-mutable-assignment
const noUnsafeOptionalPropertyAssignment = createRule({
  name: "no-unsafe-readonly-mutable-assignment",
  meta: {
    type: "problem",
    docs: {
      description: "Bans unsafe assignment to optional properties.",
      recommended: "error",
    },
    messages: {
      errorStringCallExpression: message,
      errorStringAssignmentExpression: message,
      errorStringVariableDeclaration: message,
      errorStringArrowFunctionExpression: message,
      errorStringTSAsExpression: message,
      errorStringTSTypeAssertion: message,
    },
    schema: [],
  },
  create: createNoUnsafeAssignmentRule(
    unsafePropertyAssignmentFunc,
    unsafeIndexAssignmentFunc
  ),
  defaultOptions: [],
} as const);

export default noUnsafeOptionalPropertyAssignment;
